@@ -28,10 +28,15 @@ URL = 'http://dx.doi.org/{DOI}'
 UA = 'doi2tex (gzip)'
 TO = 25
 
-doi = sys.argv[1]
 
 def usage():
     print('Usage: isbn_doi2tex DOI')
+    sys.exit(1)
+
+try:
+    doi = sys.argv[1]
+except:
+    usage()
 
 def wdata(doi):
     return query(URL.format(DOI=doi),
